package Bread::Board::LifeCycle;
BEGIN {
  $Bread::Board::LifeCycle::AUTHORITY = 'cpan:STEVAN';
}
BEGIN {
  $Bread::Board::LifeCycle::VERSION = '0.24';
}
use Moose::Role;

no Moose::Role; 1;



=pod

=head1 NAME

Bread::Board::LifeCycle

=head1 VERSION

version 0.24

=head1 DESCRIPTION

=head1 NAME

Bread::Board::LifeCycle

=head1 BUGS

All complex software has bugs lurking in it, and this module is no
exception. If you find a bug please either email me, or add the bug
to cpan-RT.

=head1 AUTHOR

Stevan Little <stevan@iinteractive.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Infinity Interactive.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

